import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController, FrameworkErrorEnum, ServiceError } from 'free-midway-component';
import { AdminService } from '../service/admin.service';
import { CDTO_admin, CVO_admin, FVO_admin, QDTO_admin, QVO_admin, UDTO_admin, UVAO_admin } from '../interface/admin.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { verifyToken } from '../decorator/verifyToken.decorator';
@ApiTags(['管理员表'])
@Controller('/admin')
export class AdminController extends BaseController {
  @Inject()
  service: AdminService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_admin })
  async create(@Body() data: CDTO_admin) {
    // 禁用!项目初始化生成
    // const dbData = await this.service.create(data);
    // const result = new CVO_admin(dbData);
    throw new ServiceError('不提供此服务', FrameworkErrorEnum.SERVICE_FAULT);
  }
  @Get('/')
  @verifyToken()
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_admin })
  async query(@Query() filter: QDTO_admin, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_admin(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @verifyToken()
  @ApiResponse({ type: FVO_admin })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_admin(data);
    return result;
  }

  @Post('/:id')
  @verifyToken()
  @Validate()
  @ApiResponse({ type: UVAO_admin })
  async update(@Param('id') id: string, @Body() body: UDTO_admin) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @verifyToken()
  @Validate()
  async delete(@Param('id') id: string) {
    // 禁用
    // await this.service.delete(id);
    // return 'ok';
    throw new ServiceError('不提供此服务', FrameworkErrorEnum.SERVICE_FAULT);
  }
  @Post('/init')
  async initData() {
    await this.service.initSuper();
    return 'ok';
  }

  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
