import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AdvService } from '../service/adv.service';
import { CDTO_adv, CVO_adv, FVO_adv, QDTO_adv, QVO_adv, UDTO_adv, UVAO_adv } from '../interface/adv.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['广告'])
@Controller('/adv')
export class AdvController extends BaseController {
  @Inject()
  service: AdvService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_adv })
  async create(@Body() data: CDTO_adv) {
    const dbData = await this.service.create(data);
    const result = new CVO_adv(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_adv })
  async query(@Query() filter: QDTO_adv, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_adv(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_adv })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_adv(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_adv })
  async update(@Param('id') id: string, @Body() body: UDTO_adv) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
