import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ChatService } from '../service/chat.service';
import { CDTO_chat, CVO_chat, FVO_chat, QDTO_chat, QVO_chat, UDTO_chat, UVAO_chat } from '../interface/chat.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { verifyToken } from '../decorator/verifyToken.decorator';
@ApiTags(['聊天记录'])
@Controller('/chat')
export class ChatController extends BaseController {
  @Inject()
  service: ChatService;

  @Get('/lcl')
  @verifyToken()
  async getLastChatRecordList(@Query('doctor') doctor: string, @Query('name') name: string, @Query('skip') skip: number, @Query('limit') limit: number) {
    const result = await this.service.getLastChatRecordList(doctor, skip, limit, name);
    return result;
  }

  @Post('/')
  @verifyToken()
  @Validate()
  @ApiResponse({ type: CVO_chat })
  async create(@Body() data: CDTO_chat) {
    const dbData = await this.service.create(data);
    const result = new CVO_chat(dbData);
    return result;
  }
  @Get('/')
  @verifyToken()
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_chat })
  async query(@Query() filter: QDTO_chat, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_chat(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @verifyToken()
  @ApiResponse({ type: FVO_chat })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_chat(data);
    return result;
  }

  @Post('/:id')
  @verifyToken()
  @Validate()
  @ApiResponse({ type: UVAO_chat })
  async update(@Param('id') id: string, @Body() body: UDTO_chat) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @verifyToken()
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
