import { Body, Controller, Del, Get, Inject, Param, Post } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ConfigService } from '../service/config.service';
import { CDTO_config, CVO_config, FVO_config, QVO_config, UDTO_config, UVAO_config } from '../interface/config.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { verifyToken } from '../decorator/verifyToken.decorator';
@ApiTags(['基础设置'])
@Controller('/config')
export class ConfigController extends BaseController {
  @Inject()
  service: ConfigService;

  @Post('/')
  @verifyToken()
  @Validate()
  @ApiResponse({ type: CVO_config })
  async create(@Body() data: CDTO_config) {
    const dbData = await this.service.create(data);
    const result = new CVO_config(dbData);
    return result;
  }
  @Get('/')
  @verifyToken()
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_config })
  async query() {
    const data = await this.service.findByOne();
    const result = new QVO_config(data);
    return result;
  }

  @Get('/:id')
  @verifyToken()
  @ApiResponse({ type: FVO_config })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_config(data);
    return result;
  }

  @Post('/:id')
  @verifyToken()
  @Validate()
  @ApiResponse({ type: UVAO_config })
  async update(@Param('id') id: string, @Body() body: UDTO_config) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @verifyToken()
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
