import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController, FrameworkErrorEnum, ServiceError } from 'free-midway-component';
import { DoctorService } from '../service/doctor.service';
import { CDTO_doctor, CVO_doctor, FVO_doctor, QDTO_doctor, QVO_doctor, UDTO_doctor, UVAO_doctor } from '../interface/doctor.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UtilService } from '../service/util.service';
import { LoginType } from '../interface/login.interface';
import { verifyToken } from '../decorator/verifyToken.decorator';
@ApiTags(['医生'])
@Controller('/doctor')
export class DoctorController extends BaseController {
  @Inject()
  service: DoctorService;
  @Inject()
  utilService: UtilService;

  @Post('/')
  @verifyToken()
  @Validate()
  @ApiResponse({ type: CVO_doctor })
  async create(@Body() data: CDTO_doctor) {
    // 检查是否有重复账户
    const has_same = await this.utilService.checkAccountIsSame(data.account, LoginType.Doctor);
    if (has_same) throw new ServiceError('账号已存在!', FrameworkErrorEnum.SERVICE_FAULT);
    const dbData = await this.service.create(data);
    const result = new CVO_doctor(dbData);
    return result;
  }
  @Get('/')
  @verifyToken()
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_doctor })
  async query(@Query() filter: QDTO_doctor, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_doctor(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @verifyToken()
  @ApiResponse({ type: FVO_doctor })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_doctor(data);
    return result;
  }

  @Post('/:id')
  @verifyToken()
  @Validate()
  @ApiResponse({ type: UVAO_doctor })
  async update(@Param('id') id: string, @Body() body: UDTO_doctor) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @verifyToken()
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
