import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { GroupService } from '../service/group.service';
import { CDTO_group, CVO_group, FVO_group, QDTO_group, QVO_group, UDTO_group, UVAO_group } from '../interface/group.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { verifyToken } from '../decorator/verifyToken.decorator';
@ApiTags(['群组'])
@Controller('/group')
export class GroupController extends BaseController {
  @Inject()
  service: GroupService;

  /**
   * 分页查询群组中病人列表
   * @param group_id 群组id
   * @param skip 分页开始索引
   * @param limit 分页显示数量
   */
  @Get('/getPaitentList')
  @verifyToken()
  async getPaitentList(@Query('groupId') groupId: string, @Query('skip') skip: number, @Query('limit') limit: number) {
    const result = await this.service.findPaitentByGroupId(groupId, skip, limit);
    return result;
  }

  @Get('/getDoctorList')
  @verifyToken()
  async getDoctorList(@Query('patientId') patientId: string, @Query('skip') skip: number, @Query('limit') limit: number) {
    const result = await this.service.findDoctorByPatientId(patientId, skip, limit);
    return result;
  }

  @Post('/')
  @verifyToken()
  @Validate()
  @ApiResponse({ type: CVO_group })
  async create(@Body() data: CDTO_group) {
    const dbData = await this.service.create(data);
    const result = new CVO_group(dbData);
    return result;
  }
  @Get('/')
  @verifyToken()
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_group })
  async query(@Query() filter: QDTO_group, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_group(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @verifyToken()
  @ApiResponse({ type: FVO_group })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_group(data);
    return result;
  }

  @Post('/:id')
  @verifyToken()
  @Validate()
  @ApiResponse({ type: UVAO_group })
  async update(@Param('id') id: string, @Body() body: UDTO_group) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @verifyToken()
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
