import { Provide, Inject } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Role } from '../entity/role.entity';
import { Menus } from '../entity/menus.entity';
import { MenusService } from './menus.service';
import flattenDeep = require('lodash/flattenDeep');
import uniq = require('lodash/uniq');
type modelType = ReturnModelType<typeof Role>;
@Provide()
export class RoleService extends BaseService<modelType> {
  @InjectEntityModel(Role)
  model: modelType;

  @InjectEntityModel(Menus)
  menusModel: ReturnModelType<typeof Menus>;

  @Inject()
  menusService: MenusService;

  /**
   * 根据角色id数组,整理菜单
   * @param roleIdList 角色id数组
   */
  async getMenuByRoles(roleIdList) {
    let menus = [];
    // 第一步,整理所有菜单至一维数组
    for (const r of roleIdList) {
      menus.push(...flattenDeep(r));
    }
    menus = uniq(menus);
    const allMenu = await this.menusModel
      .find({ _id: menus }, { meta: 0, __v: 0 })
      .sort({ order_num: 1 })
      .lean();
    let treeMenu = allMenu.filter(f => !f.parent_id);
    treeMenu = this.menusService.treeMenu(allMenu, treeMenu);
    return treeMenu;
  }
}
